pub fn decode_one(buf: &mut Vec<u8>) -> Result<Option<Frame>, CodecError>Expand description
Pulls one complete frame from buf, rejecting frames larger than
DEFAULT_MAX_FRAME_SIZE.
Errors
Same as decode_one_with_limit.
pub fn decode_one(buf: &mut Vec<u8>) -> Result<Option<Frame>, CodecError>Pulls one complete frame from buf, rejecting frames larger than
DEFAULT_MAX_FRAME_SIZE.
Same as decode_one_with_limit.